# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from tests.http_response_catcher import HttpResponseCatcher
from tester.api_helper import APIHelper
from tester.controllers.body_params_controller import BodyParamsController
from tester.models.delete_body import DeleteBody
from tester.models.additional_model_parameters import AdditionalModelParameters
from tester.models.validate import Validate
from tester.models.person import Employee
from tester.models.test_nstring_encoding import TestNstringEncoding
from tester.models.test_rstring_encoding import TestRstringEncoding
from tester.models.test_r_nstring_encoding import TestRNstringEncoding
from tester.models.unix_date_time import UnixDateTime
from tester.models.send_unix_date_time import SendUnixDateTime
from tester.models.send_rfc_1123_date_time import SendRfc1123DateTime
from tester.models.model_with_optional_rfc_1123_date_time import ModelWithOptionalRfc1123DateTime
from tester.models.model_with_optional_rfc_3339_date_time import ModelWithOptionalRfc3339DateTime
from tester.models.send_rfc_339_date_time import SendRfc339DateTime
from tester.models.uuid_as_optional import UuidAsOptional
from tester.models.boolean_as_optional import BooleanAsOptional
from tester.models.date_as_optional import DateAsOptional
from tester.models.dynamic_as_optional import DynamicAsOptional
from tester.models.string_as_optional import StringAsOptional
from tester.models.precision_as_optional import PrecisionAsOptional
from tester.models.long_as_optional import LongAsOptional
from tester.models.number_as_optional import NumberAsOptional
from tester.exceptions.global_test_exception import GlobalTestException


class BodyParamsControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(BodyParamsControllerTests, cls).setUpClass()
        cls.response_catcher = HttpResponseCatcher()
        cls.controller = BodyParamsController(cls.config, cls.response_catcher)

    def test_check_controller_type(self):
        self.assertTrue(type(self.client.body_params) is BodyParamsController)

    # Todo: Add description for test test_delete_plaintext_test
    def test_delete_plaintext_test(self):
        # Parameters for the API call
        text_string = 'farhan\nnouman'

        # Perform the API call through the SDK function
        result = self.controller.send_delete_plain_text(text_string)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_delete_body
    def test_send_delete_body(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"name":"farhan","field":"QA"}', DeleteBody.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_delete_body(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_delete_body_with_multiliner_name
    def test_send_delete_body_with_multiliner_name(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"name":"farhan\\nnouman","field":"QA"}', DeleteBody.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_delete_body(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_delete_body_with_special_field_name
    def test_send_delete_body_with_special_field_name(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"name":"farhan","field":"&&&"}', DeleteBody.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_delete_body(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_delete_body_with_blank_field
    def test_send_delete_body_with_blank_field(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"name":"farhan","field":" "}', DeleteBody.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_delete_body(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_delete_body_with_blank_name
    def test_send_delete_body_with_blank_name(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"name":" ","field":"QA"}', DeleteBody.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_delete_body(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_delete_body_with_blank_name_and_field
    def test_send_delete_body_with_blank_name_and_field(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"name":" ","field":" "}', DeleteBody.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_delete_body(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_date_array
    def test_send_date_array(self):
        # Parameters for the API call
        dates = [dateutil.parser.parse(element).date() for element in APIHelper.json_deserialize('["1994-02-13","1994-02-13"]')]

        # Perform the API call through the SDK function
        result = self.controller.send_date_array(dates)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_date
    def test_send_date(self):
        # Parameters for the API call
        date = dateutil.parser.parse('1994-02-13').date()

        # Perform the API call through the SDK function
        result = self.controller.send_date(date)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_unix_date_time
    def test_send_unix_date_time(self):
        # Parameters for the API call
        datetime = APIHelper.UnixDateTime.from_value(1484719381).datetime

        # Perform the API call through the SDK function
        result = self.controller.send_unix_date_time(datetime)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_rfc_1123_date_time
    def test_send_rfc_1123_date_time(self):
        # Parameters for the API call
        datetime = APIHelper.HttpDateTime.from_value('Sun, 06 Nov 1994 08:49:37 GMT').datetime

        # Perform the API call through the SDK function
        result = self.controller.send_rfc_1123_date_time(datetime)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_rfc_3339_date_time
    def test_send_rfc_3339_date_time(self):
        # Parameters for the API call
        datetime = APIHelper.RFC3339DateTime.from_value('1994-02-13T14:01:54.9571247Z').datetime

        # Perform the API call through the SDK function
        result = self.controller.send_rfc_3339_date_time(datetime)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_unix_date_time_array
    def test_send_unix_date_time_array(self):
        # Parameters for the API call
        datetimes = [element.datetime for element in APIHelper.json_deserialize('[1484719381,1484719381]', APIHelper.UnixDateTime.from_value)]

        # Perform the API call through the SDK function
        result = self.controller.send_unix_date_time_array(datetimes)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_rfc_1123_date_time_array
    def test_send_rfc_1123_date_time_array(self):
        # Parameters for the API call
        datetimes = [element.datetime for element in APIHelper.json_deserialize('["Sun, 06 Nov 1994 08:49:37 GMT","Sun, 06 Nov 1994 08:49:37 GMT"]', APIHelper.HttpDateTime.from_value)]

        # Perform the API call through the SDK function
        result = self.controller.send_rfc_1123_date_time_array(datetimes)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_rfc_3339_date_time_array
    def test_send_rfc_3339_date_time_array(self):
        # Parameters for the API call
        datetimes = [element.datetime for element in APIHelper.json_deserialize('["1994-02-13T14:01:54.9571247Z","1994-02-13T14:01:54.9571247Z"]', APIHelper.RFC3339DateTime.from_value)]

        # Perform the API call through the SDK function
        result = self.controller.send_rfc_3339_date_time_array(datetimes)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_string_array
    def test_send_string_array(self):
        # Parameters for the API call
        sarray = APIHelper.json_deserialize('["abc","def"]')

        # Perform the API call through the SDK function
        result = self.controller.send_string_array(sarray)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_update_string_with_body
    def test_update_string_with_body(self):
        # Parameters for the API call
        value = 'TestString'

        # Perform the API call through the SDK function
        result = self.controller.update_string(value)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_update_special_string_with_body
    def test_update_special_string_with_body(self):
        # Parameters for the API call
        value = '$%^!@#$%^&*'

        # Perform the API call through the SDK function
        result = self.controller.update_string(value)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_update_multiliner_string_with_body
    def test_update_multiliner_string_with_body(self):
        # Parameters for the API call
        value = 'TestString\nnouman'

        # Perform the API call through the SDK function
        result = self.controller.update_string(value)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_update_string_with_body_corner_case
    def test_update_string_with_body_corner_case(self):
        # Parameters for the API call
        value = ''

        # Perform the API call through the SDK function
        result = self.controller.update_string(value)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)

    # Todo: Add description for test test_send_integer_array
    def test_send_integer_array(self):
        # Parameters for the API call
        integers = APIHelper.json_deserialize('[1,2,3,4,5]')

        # Perform the API call through the SDK function
        result = self.controller.send_integer_array(integers)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_wrap_body_in_object
    def test_wrap_body_in_object(self):
        # Parameters for the API call
        field = 'QA'
        name = 'farhan'

        # Perform the API call through the SDK function
        result = self.controller.wrap_body_in_object(field, name)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_wrap_body_in_object_1
    def test_wrap_body_in_object_1(self):
        # Parameters for the API call
        field = ''
        name = 'farhan'

        # Perform the API call through the SDK function
        result = self.controller.wrap_body_in_object(field, name)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_wrap_body_in_object_2
    def test_wrap_body_in_object_2(self):
        # Parameters for the API call
        field = 'QA'
        name = ''

        # Perform the API call through the SDK function
        result = self.controller.wrap_body_in_object(field, name)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_wrap_body_in_object_3
    def test_wrap_body_in_object_3(self):
        # Parameters for the API call
        field = '$$'
        name = '$$'

        # Perform the API call through the SDK function
        result = self.controller.wrap_body_in_object(field, name)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_wrap_body_in_object_4
    def test_wrap_body_in_object_4(self):
        # Parameters for the API call
        field = 'QA&farhan'
        name = 'QA&farhan'

        # Perform the API call through the SDK function
        result = self.controller.wrap_body_in_object(field, name)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_additional_model_properties
    def test_additional_model_properties(self):
        # Parameters for the API call
        model = APIHelper.json_deserialize(
            '{"name":"farhan","field":"QA","address":"Ghori Town","Job":{"company":"API'
            'MATIC","location":"NUST"}}'
            , AdditionalModelParameters.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.additional_model_parameters(model)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_validate_required_param_test
    def test_validate_required_param_test(self):
        # Parameters for the API call
        model = APIHelper.json_deserialize('{"name":"farhan","field":"QA"}', Validate.from_dictionary)
        option = '...'

        # Perform the API call through the SDK function
        result = self.controller.validate_required_parameter(model, option)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_additional_model_properties_1
    def test_additional_model_properties_1(self):
        # Parameters for the API call
        model = APIHelper.json_deserialize(
            '{"name":"farhan","field":"QA","address":"Ghori Town","Job":{"company":"API'
            'MATIC","location":"NUST"}}'
            , AdditionalModelParameters.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.additional_model_parameters_1(model)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_model
    def test_send_model(self):
        # Parameters for the API call
        model = APIHelper.json_deserialize(
            '{"name":"Shahid Khaliq","age":5147483645,"address":"H # 531, S # 20","uid"'
            ':"123321","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z'
            '","salary":20000,"department":"Software Development","joiningDay":"Saturday'
            '","workingDays":["Monday","Tuesday","Friday"],"boss":{"personType":"Boss","'
            'name":"Zeeshan Ejaz","age":5147483645,"address":"H # 531, S # 20","uid":"12'
            '3321","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z","s'
            'alary":20000,"department":"Software Development","joiningDay":"Saturday","w'
            'orkingDays":["Monday","Tuesday","Friday"],"dependents":[{"name":"Future Wif'
            'e","age":5147483649,"address":"H # 531, S # 20","uid":"123412","birthday":"'
            '1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"},{"name":"Future Kid'
            '","age":5147483648,"address":"H # 531, S # 20","uid":"312341","birthday":"1'
            '994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"}],"hiredAt":"Sun, 06 '
            'Nov 1994 08:49:37 GMT","promotedAt":1484719381},"dependents":[{"name":"Futu'
            're Wife","age":5147483649,"address":"H # 531, S # 20","uid":"123412","birth'
            'day":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"},{"name":"Futu'
            're Kid","age":5147483648,"address":"H # 531, S # 20","uid":"312341","birthd'
            'ay":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"}],"hiredAt":"Su'
            'n, 06 Nov 1994 08:49:37 GMT"}'
            , Employee.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_model(model)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_model_array
    def test_send_model_array(self):
        # Parameters for the API call
        models = APIHelper.json_deserialize(
            '[{"name":"Shahid Khaliq","age":5147483645,"address":"H # 531, S # 20","uid'
            '":"123321","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247'
            'Z","salary":20000,"department":"Software Development","joiningDay":"Saturda'
            'y","workingDays":["Monday","Tuesday","Friday"],"boss":{"personType":"Boss",'
            '"name":"Zeeshan Ejaz","age":5147483645,"address":"H # 531, S # 20","uid":"1'
            '23321","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z","'
            'salary":20000,"department":"Software Development","joiningDay":"Saturday","'
            'workingDays":["Monday","Tuesday","Friday"],"dependents":[{"name":"Future Wi'
            'fe","age":5147483649,"address":"H # 531, S # 20","uid":"123412","birthday":'
            '"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"},{"name":"Future Ki'
            'd","age":5147483648,"address":"H # 531, S # 20","uid":"312341","birthday":"'
            '1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"}],"hiredAt":"Sun, 06'
            ' Nov 1994 08:49:37 GMT","promotedAt":1484719381},"dependents":[{"name":"Fut'
            'ure Wife","age":5147483649,"address":"H # 531, S # 20","uid":"123412","birt'
            'hday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"},{"name":"Fut'
            'ure Kid","age":5147483648,"address":"H # 531, S # 20","uid":"312341","birth'
            'day":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"}],"hiredAt":"S'
            'un, 06 Nov 1994 08:49:37 GMT"},{"name":"Shahid Khaliq","age":5147483645,"ad'
            'dress":"H # 531, S # 20","uid":"123321","birthday":"1994-02-13","birthtime"'
            ':"1994-02-13T14:01:54.9571247Z","salary":20000,"department":"Software Devel'
            'opment","joiningDay":"Saturday","workingDays":["Monday","Tuesday","Friday"]'
            ',"boss":{"personType":"Boss","name":"Zeeshan Ejaz","age":5147483645,"addres'
            's":"H # 531, S # 20","uid":"123321","birthday":"1994-02-13","birthtime":"19'
            '94-02-13T14:01:54.9571247Z","salary":20000,"department":"Software Developme'
            'nt","joiningDay":"Saturday","workingDays":["Monday","Tuesday","Friday"],"de'
            'pendents":[{"name":"Future Wife","age":5147483649,"address":"H # 531, S # 2'
            '0","uid":"123412","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.'
            '9571247Z"},{"name":"Future Kid","age":5147483648,"address":"H # 531, S # 20'
            '","uid":"312341","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9'
            '571247Z"}],"hiredAt":"Sun, 06 Nov 1994 08:49:37 GMT","promotedAt":148471938'
            '1},"dependents":[{"name":"Future Wife","age":5147483649,"address":"H # 531,'
            ' S # 20","uid":"123412","birthday":"1994-02-13","birthtime":"1994-02-13T14:'
            '01:54.9571247Z"},{"name":"Future Kid","age":5147483648,"address":"H # 531, '
            'S # 20","uid":"312341","birthday":"1994-02-13","birthtime":"1994-02-13T14:0'
            '1:54.9571247Z"}],"hiredAt":"Sun, 06 Nov 1994 08:49:37 GMT"}]'
            , Employee.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_model_array(models)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_dynamic
    def test_send_dynamic(self):
        # Parameters for the API call
        dynamic = APIHelper.json_deserialize('{"uid":"1123213","name":"Shahid"}')

        # Perform the API call through the SDK function
        result = self.controller.send_dynamic(dynamic)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_string
    def test_send_string(self):
        # Parameters for the API call
        value = 'TestString'

        # Perform the API call through the SDK function
        result = self.controller.send_string(value)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_multiliner_string
    def test_send_multiliner_string(self):
        # Parameters for the API call
        value = 'TestString\nnouman'

        # Perform the API call through the SDK function
        result = self.controller.send_string(value)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_string_with_special_characters
    def test_send_string_with_special_characters(self):
        # Parameters for the API call
        value = '$%^!@#$%^&*'

        # Perform the API call through the SDK function
        result = self.controller.send_string(value)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_string_with_only_space
    def test_send_string_with_only_space(self):
        # Parameters for the API call
        value = ' '

        # Perform the API call through the SDK function
        result = self.controller.send_string(value)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_string_enum_array
    def test_send_string_enum_array(self):
        # Parameters for the API call
        days = APIHelper.json_deserialize('["Tuesday","Saturday","Wednesday","Monday","Sunday"]')

        # Perform the API call through the SDK function
        result = self.controller.send_string_enum_array(days)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_integer_enum_array
    def test_send_integer_enum_array(self):
        # Parameters for the API call
        suites = APIHelper.json_deserialize('[1,3,4,2,3]')

        # Perform the API call through the SDK function
        result = self.controller.send_integer_enum_array(suites)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_update_model_with_body
    def test_update_model_with_body(self):
        # Parameters for the API call
        model = APIHelper.json_deserialize(
            '{"name":"Shahid Khaliq","age":5147483645,"address":"H # 531, S # 20","uid"'
            ':"123321","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z'
            '","salary":20000,"department":"Software Development","joiningDay":"Saturday'
            '","workingDays":["Monday","Tuesday","Friday"],"boss":{"personType":"Boss","'
            'name":"Zeeshan Ejaz","age":5147483645,"address":"H # 531, S # 20","uid":"12'
            '3321","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z","s'
            'alary":20000,"department":"Software Development","joiningDay":"Saturday","w'
            'orkingDays":["Monday","Tuesday","Friday"],"dependents":[{"name":"Future Wif'
            'e","age":5147483649,"address":"H # 531, S # 20","uid":"123412","birthday":"'
            '1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"},{"name":"Future Kid'
            '","age":5147483648,"address":"H # 531, S # 20","uid":"312341","birthday":"1'
            '994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"}],"hiredAt":"Sun, 06 '
            'Nov 1994 08:49:37 GMT","promotedAt":1484719381},"dependents":[{"name":"Futu'
            're Wife","age":5147483649,"address":"H # 531, S # 20","uid":"123412","birth'
            'day":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"},{"name":"Futu'
            're Kid","age":5147483648,"address":"H # 531, S # 20","uid":"312341","birthd'
            'ay":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"}],"hiredAt":"Su'
            'n, 06 Nov 1994 08:49:37 GMT"}'
            , Employee.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.update_model(model)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_delete_body_with_model
    def test_send_delete_body_with_model(self):
        # Parameters for the API call
        model = APIHelper.json_deserialize(
            '{"name":"Shahid Khaliq","age":5147483645,"address":"H # 531, S # 20","uid"'
            ':"123321","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z'
            '","salary":20000,"department":"Software Development","joiningDay":"Saturday'
            '","workingDays":["Monday","Tuesday","Friday"],"boss":{"personType":"Boss","'
            'name":"Zeeshan Ejaz","age":5147483645,"address":"H # 531, S # 20","uid":"12'
            '3321","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z","s'
            'alary":20000,"department":"Software Development","joiningDay":"Saturday","w'
            'orkingDays":["Monday","Tuesday","Friday"],"dependents":[{"name":"Future Wif'
            'e","age":5147483649,"address":"H # 531, S # 20","uid":"123412","birthday":"'
            '1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"},{"name":"Future Kid'
            '","age":5147483648,"address":"H # 531, S # 20","uid":"312341","birthday":"1'
            '994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"}],"hiredAt":"Sun, 06 '
            'Nov 1994 08:49:37 GMT","promotedAt":1484719381},"dependents":[{"name":"Futu'
            're Wife","age":5147483649,"address":"H # 531, S # 20","uid":"123412","birth'
            'day":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"},{"name":"Futu'
            're Kid","age":5147483648,"address":"H # 531, S # 20","uid":"312341","birthd'
            'ay":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"}],"hiredAt":"Su'
            'n, 06 Nov 1994 08:49:37 GMT"}'
            , Employee.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_delete_body_with_model(model)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_delete_body_with_model_array
    def test_send_delete_body_with_model_array(self):
        # Parameters for the API call
        models = APIHelper.json_deserialize(
            '[{"name":"Shahid Khaliq","age":5147483645,"address":"H # 531, S # 20","uid'
            '":"123321","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247'
            'Z","salary":20000,"department":"Software Development","joiningDay":"Saturda'
            'y","workingDays":["Monday","Tuesday","Friday"],"boss":{"personType":"Boss",'
            '"name":"Zeeshan Ejaz","age":5147483645,"address":"H # 531, S # 20","uid":"1'
            '23321","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z","'
            'salary":20000,"department":"Software Development","joiningDay":"Saturday","'
            'workingDays":["Monday","Tuesday","Friday"],"dependents":[{"name":"Future Wi'
            'fe","age":5147483649,"address":"H # 531, S # 20","uid":"123412","birthday":'
            '"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"},{"name":"Future Ki'
            'd","age":5147483648,"address":"H # 531, S # 20","uid":"312341","birthday":"'
            '1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"}],"hiredAt":"Sun, 06'
            ' Nov 1994 08:49:37 GMT","promotedAt":1484719381},"dependents":[{"name":"Fut'
            'ure Wife","age":5147483649,"address":"H # 531, S # 20","uid":"123412","birt'
            'hday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"},{"name":"Fut'
            'ure Kid","age":5147483648,"address":"H # 531, S # 20","uid":"312341","birth'
            'day":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"}],"hiredAt":"S'
            'un, 06 Nov 1994 08:49:37 GMT"},{"name":"Shahid Khaliq","age":5147483645,"ad'
            'dress":"H # 531, S # 20","uid":"123321","birthday":"1994-02-13","birthtime"'
            ':"1994-02-13T14:01:54.9571247Z","salary":20000,"department":"Software Devel'
            'opment","joiningDay":"Saturday","workingDays":["Monday","Tuesday","Friday"]'
            ',"boss":{"personType":"Boss","name":"Zeeshan Ejaz","age":5147483645,"addres'
            's":"H # 531, S # 20","uid":"123321","birthday":"1994-02-13","birthtime":"19'
            '94-02-13T14:01:54.9571247Z","salary":20000,"department":"Software Developme'
            'nt","joiningDay":"Saturday","workingDays":["Monday","Tuesday","Friday"],"de'
            'pendents":[{"name":"Future Wife","age":5147483649,"address":"H # 531, S # 2'
            '0","uid":"123412","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.'
            '9571247Z"},{"name":"Future Kid","age":5147483648,"address":"H # 531, S # 20'
            '","uid":"312341","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9'
            '571247Z"}],"hiredAt":"Sun, 06 Nov 1994 08:49:37 GMT","promotedAt":148471938'
            '1},"dependents":[{"name":"Future Wife","age":5147483649,"address":"H # 531,'
            ' S # 20","uid":"123412","birthday":"1994-02-13","birthtime":"1994-02-13T14:'
            '01:54.9571247Z"},{"name":"Future Kid","age":5147483648,"address":"H # 531, '
            'S # 20","uid":"312341","birthday":"1994-02-13","birthtime":"1994-02-13T14:0'
            '1:54.9571247Z"}],"hiredAt":"Sun, 06 Nov 1994 08:49:37 GMT"}]'
            , Employee.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_delete_body_with_model_array(models)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_update_model_array_with_body
    def test_update_model_array_with_body(self):
        # Parameters for the API call
        models = APIHelper.json_deserialize(
            '[{"name":"Shahid Khaliq","age":5147483645,"address":"H # 531, S # 20","uid'
            '":"123321","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247'
            'Z","salary":20000,"department":"Software Development","joiningDay":"Saturda'
            'y","workingDays":["Monday","Tuesday","Friday"],"boss":{"personType":"Boss",'
            '"name":"Zeeshan Ejaz","age":5147483645,"address":"H # 531, S # 20","uid":"1'
            '23321","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z","'
            'salary":20000,"department":"Software Development","joiningDay":"Saturday","'
            'workingDays":["Monday","Tuesday","Friday"],"dependents":[{"name":"Future Wi'
            'fe","age":5147483649,"address":"H # 531, S # 20","uid":"123412","birthday":'
            '"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"},{"name":"Future Ki'
            'd","age":5147483648,"address":"H # 531, S # 20","uid":"312341","birthday":"'
            '1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"}],"hiredAt":"Sun, 06'
            ' Nov 1994 08:49:37 GMT","promotedAt":1484719381},"dependents":[{"name":"Fut'
            'ure Wife","age":5147483649,"address":"H # 531, S # 20","uid":"123412","birt'
            'hday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"},{"name":"Fut'
            'ure Kid","age":5147483648,"address":"H # 531, S # 20","uid":"312341","birth'
            'day":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"}],"hiredAt":"S'
            'un, 06 Nov 1994 08:49:37 GMT"},{"name":"Shahid Khaliq","age":5147483645,"ad'
            'dress":"H # 531, S # 20","uid":"123321","birthday":"1994-02-13","birthtime"'
            ':"1994-02-13T14:01:54.9571247Z","salary":20000,"department":"Software Devel'
            'opment","joiningDay":"Saturday","workingDays":["Monday","Tuesday","Friday"]'
            ',"boss":{"personType":"Boss","name":"Zeeshan Ejaz","age":5147483645,"addres'
            's":"H # 531, S # 20","uid":"123321","birthday":"1994-02-13","birthtime":"19'
            '94-02-13T14:01:54.9571247Z","salary":20000,"department":"Software Developme'
            'nt","joiningDay":"Saturday","workingDays":["Monday","Tuesday","Friday"],"de'
            'pendents":[{"name":"Future Wife","age":5147483649,"address":"H # 531, S # 2'
            '0","uid":"123412","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.'
            '9571247Z"},{"name":"Future Kid","age":5147483648,"address":"H # 531, S # 20'
            '","uid":"312341","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9'
            '571247Z"}],"hiredAt":"Sun, 06 Nov 1994 08:49:37 GMT","promotedAt":148471938'
            '1},"dependents":[{"name":"Future Wife","age":5147483649,"address":"H # 531,'
            ' S # 20","uid":"123412","birthday":"1994-02-13","birthtime":"1994-02-13T14:'
            '01:54.9571247Z"},{"name":"Future Kid","age":5147483648,"address":"H # 531, '
            'S # 20","uid":"312341","birthday":"1994-02-13","birthtime":"1994-02-13T14:0'
            '1:54.9571247Z"}],"hiredAt":"Sun, 06 Nov 1994 08:49:37 GMT"}]'
            , Employee.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.update_model_array(models)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_update_string_with_body_1
    def test_update_string_with_body_1(self):
        # Parameters for the API call
        value = 'TestString'

        # Perform the API call through the SDK function
        result = self.controller.update_string_1(value)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_update_special_string_with_body_1
    def test_update_special_string_with_body_1(self):
        # Parameters for the API call
        value = '$%^!@#$%^&*'

        # Perform the API call through the SDK function
        result = self.controller.update_string_1(value)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_update_multiliner_string_with_body_1
    def test_update_multiliner_string_with_body_1(self):
        # Parameters for the API call
        value = 'TestString\nnouman'

        # Perform the API call through the SDK function
        result = self.controller.update_string_1(value)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_update_string_with_body_corner_case_1
    def test_update_string_with_body_corner_case_1(self):
        # Parameters for the API call
        value = ' '

        # Perform the API call through the SDK function
        result = self.controller.update_string_1(value)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_update_empty_string_with_body
    def test_update_empty_string_with_body(self):
        # Parameters for the API call
        value = ''

        # Perform the API call through the SDK function
        result = self.controller.update_string_1(value)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)

    # Todo: Add description for test test_update_string_array_with_body
    def test_update_string_array_with_body(self):
        # Parameters for the API call
        strings = APIHelper.json_deserialize('["abc","def"]')

        # Perform the API call through the SDK function
        result = self.controller.update_string_array(strings)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_string_with_new_line_1
    def test_send_string_with_new_line_1(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"name":"farhan","field":"QA"}', TestNstringEncoding.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_string_with_new_line(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_string_with_new_line_2
    def test_send_string_with_new_line_2(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"name":"farhan","field":"QA&Dev"}', TestNstringEncoding.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_string_with_new_line(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_string_with_new_line_3
    def test_send_string_with_new_line_3(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"name":"farhan&nouman","field":"QA"}', TestNstringEncoding.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_string_with_new_line(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_string_with_r_1
    def test_send_string_with_r_1(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"name":"farhan","field":"QA"}', TestRstringEncoding.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_string_with_r(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_string_with_r_2
    def test_send_string_with_r_2(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"name":"farhan","field":"QA&Dev"}', TestRstringEncoding.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_string_with_r(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_string_with_r_3
    def test_send_string_with_r_3(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"name":"farhan&nouman","field":"QA"}', TestRstringEncoding.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_string_with_r(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_string_in_body_with_r_n_1
    def test_send_string_in_body_with_r_n_1(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"name":"farhan","field":"QA"}', TestRNstringEncoding.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_string_in_body_with_r_n(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_string_in_body_with_r_n_2
    def test_send_string_in_body_with_r_n_2(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"name":"farhan","field":"QA&Dev"}', TestRNstringEncoding.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_string_in_body_with_r_n(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_string_in_body_with_r_n_3
    def test_send_string_in_body_with_r_n_3(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"name":"farhan&nouman","field":"QA"}', TestRNstringEncoding.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_string_in_body_with_r_n(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_optional_unix_time_stamp_in_body
    def test_send_optional_unix_time_stamp_in_body(self):
        # Parameters for the API call
        date_time = APIHelper.UnixDateTime.from_value(1484719381).datetime

        # Perform the API call through the SDK function
        result = self.controller.send_optional_unix_date_time_in_body(date_time)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_optional_rfc_1123_in_body
    def test_send_optional_rfc_1123_in_body(self):
        # Parameters for the API call
        body = APIHelper.HttpDateTime.from_value('Sun, 06 Nov 1994 08:49:37 GMT').datetime

        # Perform the API call through the SDK function
        result = self.controller.send_optional_rfc_1123_in_body(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_test_sending_datetime_as_optional_in_plain_text_body
    def test_test_sending_datetime_as_optional_in_plain_text_body(self):
        # Parameters for the API call
        body = APIHelper.RFC3339DateTime.from_value('1994-02-13T14:01:54.9571247Z').datetime

        # Perform the API call through the SDK function
        result = self.controller.send_datetime_optional_in_endpoint(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_optional_unix_time_stamp_in_model_body
    def test_send_optional_unix_time_stamp_in_model_body(self):
        # Parameters for the API call
        date_time = APIHelper.json_deserialize('{"dateTime":1484719381}', UnixDateTime.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_optional_unix_time_stamp_in_model_body(date_time)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_optional_unix_time_stamp_in_nested_model_body
    def test_send_optional_unix_time_stamp_in_nested_model_body(self):
        # Parameters for the API call
        date_time = APIHelper.json_deserialize('{"dateTime":{"dateTime":1484719381}}', SendUnixDateTime.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_optional_unix_time_stamp_in_nested_model_body(date_time)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_test_sending_rfc_1123_date_time_in_nested_mode
    def test_test_sending_rfc_1123_date_time_in_nested_mode(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"dateTime":{"dateTime":"Sun, 06 Nov 1994 08:49:37 GMT"}}', SendRfc1123DateTime.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_rfc_1123_date_time_in_nested_model(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_optional_rfc_1123_date_time_in_model_body
    def test_send_optional_rfc_1123_date_time_in_model_body(self):
        # Parameters for the API call
        date_time = APIHelper.json_deserialize('{"dateTime":"Sun, 06 Nov 1994 08:49:37 GMT"}', ModelWithOptionalRfc1123DateTime.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_rfc_1123_date_time_in_model(date_time)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_optional_datetime_in_model_as_body
    def test_send_optional_datetime_in_model_as_body(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"dateTime":"1994-02-13T14:01:54.9571247Z"}', ModelWithOptionalRfc3339DateTime.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_optional_datetime_in_model(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_rfc_3339_date_time_in_nested_model
    def test_send_rfc_3339_date_time_in_nested_model(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"dateTime":{"dateTime":"1994-02-13T14:01:54.9571247Z"}}', SendRfc339DateTime.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_rfc_339_date_time_in_nested_models(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_uuid_as_optional
    def test_uuid_as_optional(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"uuid":"123e4567-e89b-12d3-a456-426655440000"}', UuidAsOptional.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.uuid_as_optional(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_boolean_as_optional
    def test_boolean_as_optional(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"boolean":true}', BooleanAsOptional.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.boolean_as_optional(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_date_as_optional
    def test_date_as_optional(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"date":"1994-02-13"}', DateAsOptional.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.date_as_optional(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_dynamic_as_optional
    def test_dynamic_as_optional(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"dynamic":{"dynamic":"test"}}', DynamicAsOptional.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.dynamic_as_optional(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_string_as_optional
    def test_string_as_optional(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"string":"test"}', StringAsOptional.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.string_as_optional(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_precision_as_optional
    def test_precision_as_optional(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"precision":1.23}', PrecisionAsOptional.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.precision_as_optional(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_long_as_optional
    def test_long_as_optional(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"long":123123}', LongAsOptional.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.long_as_optional(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_number_as_optional
    def test_number_as_optional(self):
        # Parameters for the API call
        body = APIHelper.json_deserialize('{"number":1}', NumberAsOptional.from_dictionary)

        # Perform the API call through the SDK function
        result = self.controller.send_number_as_optional(body)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))





# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from tests.http_response_catcher import HttpResponseCatcher
from tester.api_helper import APIHelper
from tester.controllers.response_types_controller import ResponseTypesController


class ResponseTypesControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(ResponseTypesControllerTests, cls).setUpClass()
        cls.response_catcher = HttpResponseCatcher()
        cls.controller = ResponseTypesController(cls.config, cls.response_catcher)

    def test_check_controller_type(self):
        self.assertTrue(type(self.client.response_types) is ResponseTypesController)

    # Todo: Add description for test test_get_date_array
    def test_get_date_array(self):

        # Perform the API call through the SDK function
        result = self.controller.get_date_array()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('["1994-02-13","1994-02-13"]')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body))


    # Todo: Add description for test test_get_date
    def test_get_date(self):

        # Perform the API call through the SDK function
        result = self.controller.get_date()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        self.assertEqual('1994-02-13', self.response_catcher.response.raw_body)


    # Todo: Add description for test test_return_company_model
    def test_return_company_model(self):

        # Perform the API call through the SDK function
        result = self.controller.return_company_model()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"company name":"APIMatic","address":"nust","cell number":"090078601"}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_return_boss_model
    def test_return_boss_model(self):

        # Perform the API call through the SDK function
        result = self.controller.return_boss_model()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize(
            '{"company name":"APIMatic","address":"nust","cell number":"090078601","fir'
            'st name":"Adeel","last name":"Ali","address_boss":"nust"}'
            )
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_return_employee_model
    def test_return_employee_model(self):

        # Perform the API call through the SDK function
        result = self.controller.return_employee_model()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize(
            '{"company name":"APIMatic","address":"nust","cell number":"090078601","fir'
            'st name":"Nauman","last name":"Ali","id":"123456"}'
            )
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_return_developer_model
    def test_return_developer_model(self):

        # Perform the API call through the SDK function
        result = self.controller.return_developer_model()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize(
            '{"company name":"APIMatic","address":"nust","cell number":"090078601","fir'
            'st name":"Nauman","last name":"Ali","id":"123456","team":"CORE","designatio'
            'n":"Manager","role":"Team Lead"}'
            )
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_return_tester_model
    def test_return_tester_model(self):

        # Perform the API call through the SDK function
        result = self.controller.return_tester_model()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize(
            '{"company name":"APIMatic","address":"nust","cell number":"090078601","fir'
            'st name":"Muhammad","last name":"Farhan","id":"123456","team":"Testing","de'
            'signation":"Tester","role":"Testing"}'
            )
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_return_complex_1_object
    def test_return_complex_1_object(self):

        # Perform the API call through the SDK function
        result = self.controller.return_complex_1_object()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize(
            '{"medications":[{"aceInhibitors":[{"name":"lisinopril","strength":"10 mg T'
            'ab","dose":"1 tab","route":"PO","sig":"daily","pillCount":"#90","refills":"'
            'Refill 3"}],"antianginal":[{"name":"nitroglycerin","strength":"0.4 mg Subli'
            'ngual Tab","dose":"1 tab","route":"SL","sig":"q15min PRN","pillCount":"#30"'
            ',"refills":"Refill 1"}],"anticoagulants":[{"name":"warfarin sodium","streng'
            'th":"3 mg Tab","dose":"1 tab","route":"PO","sig":"daily","pillCount":"#90",'
            '"refills":"Refill 3"}],"betaBlocker":[{"name":"metoprolol tartrate","streng'
            'th":"25 mg Tab","dose":"1 tab","route":"PO","sig":"daily","pillCount":"#90"'
            ',"refills":"Refill 3"}],"diuretic":[{"name":"furosemide","strength":"40 mg '
            'Tab","dose":"1 tab","route":"PO","sig":"daily","pillCount":"#90","refills":'
            '"Refill 3"}],"mineral":[{"name":"potassium chloride ER","strength":"10 mEq '
            'Tab","dose":"1 tab","route":"PO","sig":"daily","pillCount":"#90","refills":'
            '"Refill 3"}]}],"labs":[{"name":"Arterial Blood Gas","time":"Today","locatio'
            'n":"Main Hospital Lab"},{"name":"BMP","time":"Today","location":"Primary Ca'
            're Clinic"},{"name":"BNP","time":"3 Weeks","location":"Primary Care Clinic"'
            '},{"name":"BUN","time":"1 Year","location":"Primary Care Clinic"},{"name":"'
            'Cardiac Enzymes","time":"Today","location":"Primary Care Clinic"},{"name":"'
            'CBC","time":"1 Year","location":"Primary Care Clinic"},{"name":"Creatinine"'
            ',"time":"1 Year","location":"Main Hospital Lab"},{"name":"Electrolyte Panel'
            '","time":"1 Year","location":"Primary Care Clinic"},{"name":"Glucose","time'
            '":"1 Year","location":"Main Hospital Lab"},{"name":"PT/INR","time":"3 Weeks'
            '","location":"Primary Care Clinic"},{"name":"PTT","time":"3 Weeks","locatio'
            'n":"Coumadin Clinic"},{"name":"TSH","time":"1 Year","location":"Primary Car'
            'e Clinic"}],"imaging":[{"name":"Chest X-Ray","time":"Today","location":"Mai'
            'n Hospital Radiology"},{"name":"Chest X-Ray","time":"Today","location":"Mai'
            'n Hospital Radiology"},{"name":"Chest X-Ray","time":"Today","location":"Mai'
            'n Hospital Radiology"}]}'
            )
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_return_response_with_enum_object
    def test_return_response_with_enum_object(self):

        # Perform the API call through the SDK function
        result = self.controller.return_response_with_enums()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize(
            '{"paramFormat":"Template","optional":false,"type":"Long","constant":false,'
            '"isArray":false,"isStream":false,"isAttribute":false,"isMap":false,"attribu'
            'tes":{"exclusiveMaximum":false,"exclusiveMinimum":false,"id":"5a9fcb01caacc'
            '310dc6bab51"},"nullable":false,"id":"5a9fcb01caacc310dc6bab50","name":"petI'
            'd","description":"ID of pet to update"}'
            )
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_return_complex_2_object
    def test_return_complex_2_object(self):

        # Perform the API call through the SDK function
        result = self.controller.return_complex_2_object()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize(
            '{"glossary":{"title":"example glossary","GlossDiv":{"title":"S","GlossList'
            '":{"GlossEntry":{"ID":"SGML","SortAs":"SGML","GlossTerm":"Standard Generali'
            'zed Markup Language","Acronym":"SGML","Abbrev":"ISO 8879:1986","GlossDef":{'
            '"para":"A meta-markup language, used to create markup languages such as Doc'
            'Book.","GlossSeeAlso":["GML","XML"]},"GlossSee":"markup"}}}}}'
            )
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_return_complex_3_object
    def test_return_complex_3_object(self):

        # Perform the API call through the SDK function
        result = self.controller.return_complex_3_object()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize(
            '{"documentId":"099cceda-38a8-4b01-87b9-a8f2007675d6","signers":[{"id":"1be'
            'f97d1-0704-4eb2-a490-a8f2007675db","url":"https://sign-test.idfy.io/start?j'
            'wt=eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzM4NCJ9.eyJrdmVyc2lvbiI6IjdmNzhjNzNkMmQ1MjQ'
            'zZWRiYjdiNDI0MmI2MDE1MWU4IiwiZG9jaWQiOiIwOTljY2VkYS0zOGE4LTRiMDEtODdiOS1hOG'
            'YyMDA3Njc1ZDYiLCJhaWQiOiJjMGNlMTQ2OC1hYzk0LTRiMzQtODc2ZS1hODg1MDBjMmI5YTEiL'
            'CJsZyI6ImVuIiwiZXJyIjpudWxsLCJpZnIiOmZhbHNlLCJ3Ym1zZyI6ZmFsc2UsInNmaWQiOiIx'
            'YmVmOTdkMS0wNzA0LTRlYjItYTQ5MC1hOGYyMDA3Njc1ZGIiLCJ1cmxleHAiOm51bGwsImF0aCI'
            '6bnVsbCwiZHQiOiJUZXN0IGRvY3VtZW50IiwidmYiOmZhbHNlLCJhbiI6IklkZnkgU0RLIGRlbW'
            '8iLCJ0aCI6IlBpbmsiLCJzcCI6IkN1YmVzIiwiZG9tIjpudWxsLCJyZGlyIjpmYWxzZSwidXQiO'
            'iJ3ZWIiLCJ1dHYiOm51bGwsInNtIjoidGVzdEB0ZXN0LmNvbSJ9.Dyy2RSeR6dmU8qxOEi-2gEX'
            '3Gg7wry6JhkZIWOuADDdu5jJWidQLcxfJn_qAHNpb","links":[],"externalSignerId":"u'
            'oiahsd321982983jhrmnec2wsadm32","redirectSettings":{"redirectMode":"donot_r'
            'edirect"},"signatureType":{"mechanism":"pkisignature","onEacceptUseHandWrit'
            'tenSignature":false},"ui":{"dialogs":{"before":{"useCheckBox":false,"title"'
            ':"Info","message":"Please read the contract on the next pages carefully. Pa'
            'y some extra attention to paragraph 5."}},"language":"EN","styling":{"color'
            'Theme":"Pink","spinner":"Cubes"}},"tags":[],"order":0,"required":false}],"s'
            'tatus":{"documentStatus":"unsigned","completedPackages":[],"attachmentPacka'
            'ges":{}},"title":"Test document","description":"This is an important docume'
            'nt","externalId":"ae7b9ca7-3839-4e0d-a070-9f14bffbbf55","dataToSign":{"file'
            'Name":"sample.txt","convertToPDF":false},"contactDetails":{"email":"test@te'
            'st.com","url":"https://idfy.io"},"advanced":{"tags":["develop","fun_with_do'
            'cuments"],"attachments":0,"requiredSignatures":0,"getSocialSecurityNumber":'
            'false,"timeToLive":{"deadline":"2018-06-29T14:57:25Z","deleteAfterHours":1}'
            '}}'
            )
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_get_long
    def test_get_long(self):

        # Perform the API call through the SDK function
        result = self.controller.get_long()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        self.assertEqual('5147483647', self.response_catcher.response.raw_body)


    # Todo: Add description for test test_get_model
    def test_get_model(self):

        # Perform the API call through the SDK function
        result = self.controller.get_model()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize(
            '{"name":"Shahid Khaliq","age":5147483645,"address":"H # 531, S # 20","uid"'
            ':"123321","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z'
            '","salary":20000,"department":"Software Development","joiningDay":"Saturday'
            '","workingDays":["Monday","Tuesday","Friday"],"boss":{"personType":"Boss","'
            'name":"Zeeshan Ejaz","age":5147483645,"address":"H # 531, S # 20","uid":"12'
            '3321","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z","s'
            'alary":20000,"department":"Software Development","joiningDay":"Saturday","w'
            'orkingDays":["Monday","Tuesday","Friday"],"dependents":[{"name":"Future Wif'
            'e","age":5147483649,"address":"H # 531, S # 20","uid":"123412","birthday":"'
            '1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"},{"name":"Future Kid'
            '","age":5147483648,"address":"H # 531, S # 20","uid":"312341","birthday":"1'
            '994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"}],"hiredAt":"Sun, 06 '
            'Nov 1994 08:49:37 GMT","promotedAt":1484719381},"dependents":[{"name":"Futu'
            're Wife","age":5147483649,"address":"H # 531, S # 20","uid":"123412","birth'
            'day":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"},{"name":"Futu'
            're Kid","age":5147483648,"address":"H # 531, S # 20","uid":"312341","birthd'
            'ay":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"}],"hiredAt":"Su'
            'n, 06 Nov 1994 08:49:37 GMT"}'
            )
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_get_string_enum_array
    def test_get_string_enum_array(self):

        # Perform the API call through the SDK function
        result = self.controller.get_string_enum_array()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('["Tuesday","Saturday","Wednesday","Monday","Sunday"]')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body))


    # Todo: Add description for test test_get_string_enum
    def test_get_string_enum(self):

        # Perform the API call through the SDK function
        result = self.controller.get_string_enum()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        self.assertEqual('Monday', self.response_catcher.response.raw_body)


    # Todo: Add description for test test_get_model_array
    def test_get_model_array(self):

        # Perform the API call through the SDK function
        result = self.controller.get_model_array()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize(
            '[{"name":"Shahid Khaliq","age":5147483645,"address":"H # 531, S # 20","uid'
            '":"123321","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247'
            'Z","salary":20000,"department":"Software Development","joiningDay":"Saturda'
            'y","workingDays":["Monday","Tuesday","Friday"],"boss":{"personType":"Boss",'
            '"name":"Zeeshan Ejaz","age":5147483645,"address":"H # 531, S # 20","uid":"1'
            '23321","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z","'
            'salary":20000,"department":"Software Development","joiningDay":"Saturday","'
            'workingDays":["Monday","Tuesday","Friday"],"dependents":[{"name":"Future Wi'
            'fe","age":5147483649,"address":"H # 531, S # 20","uid":"123412","birthday":'
            '"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"},{"name":"Future Ki'
            'd","age":5147483648,"address":"H # 531, S # 20","uid":"312341","birthday":"'
            '1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"}],"hiredAt":"Sun, 06'
            ' Nov 1994 08:49:37 GMT","promotedAt":1484719381},"dependents":[{"name":"Fut'
            'ure Wife","age":5147483649,"address":"H # 531, S # 20","uid":"123412","birt'
            'hday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"},{"name":"Fut'
            'ure Kid","age":5147483648,"address":"H # 531, S # 20","uid":"312341","birth'
            'day":"1994-02-13","birthtime":"1994-02-13T14:01:54.9571247Z"}],"hiredAt":"S'
            'un, 06 Nov 1994 08:49:37 GMT"},{"name":"Shahid Khaliq","age":5147483645,"ad'
            'dress":"H # 531, S # 20","uid":"123321","birthday":"1994-02-13","birthtime"'
            ':"1994-02-13T14:01:54.9571247Z","salary":20000,"department":"Software Devel'
            'opment","joiningDay":"Saturday","workingDays":["Monday","Tuesday","Friday"]'
            ',"boss":{"personType":"Boss","name":"Zeeshan Ejaz","age":5147483645,"addres'
            's":"H # 531, S # 20","uid":"123321","birthday":"1994-02-13","birthtime":"19'
            '94-02-13T14:01:54.9571247Z","salary":20000,"department":"Software Developme'
            'nt","joiningDay":"Saturday","workingDays":["Monday","Tuesday","Friday"],"de'
            'pendents":[{"name":"Future Wife","age":5147483649,"address":"H # 531, S # 2'
            '0","uid":"123412","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.'
            '9571247Z"},{"name":"Future Kid","age":5147483648,"address":"H # 531, S # 20'
            '","uid":"312341","birthday":"1994-02-13","birthtime":"1994-02-13T14:01:54.9'
            '571247Z"}],"hiredAt":"Sun, 06 Nov 1994 08:49:37 GMT","promotedAt":148471938'
            '1},"dependents":[{"name":"Future Wife","age":5147483649,"address":"H # 531,'
            ' S # 20","uid":"123412","birthday":"1994-02-13","birthtime":"1994-02-13T14:'
            '01:54.9571247Z"},{"name":"Future Kid","age":5147483648,"address":"H # 531, '
            'S # 20","uid":"312341","birthday":"1994-02-13","birthtime":"1994-02-13T14:0'
            '1:54.9571247Z"}],"hiredAt":"Sun, 06 Nov 1994 08:49:37 GMT"}]'
            )
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_get_int_enum
    def test_get_int_enum(self):

        # Perform the API call through the SDK function
        result = self.controller.get_int_enum()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        self.assertEqual('3', self.response_catcher.response.raw_body)


    # Todo: Add description for test test_get_int_enum_array
    def test_get_int_enum_array(self):

        # Perform the API call through the SDK function
        result = self.controller.get_int_enum_array()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('[1,3,4,2,3]')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body))


    # Todo: Add description for test test_get_precision
    def test_get_precision(self):

        # Perform the API call through the SDK function
        result = self.controller.get_precision()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        self.assertEqual('4.999', self.response_catcher.response.raw_body)


    # Todo: Add description for test test_get_binary
    def test_get_binary(self):

        # Perform the API call through the SDK function
        result = self.controller.get_binary()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        self.assertEqual(TestHelper.get_file('http://localhost:3000/response/image').read(), self.response_catcher.response.raw_body)


    # Todo: Add description for test test_get_integer
    def test_get_integer(self):

        # Perform the API call through the SDK function
        result = self.controller.get_integer()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        self.assertEqual('4', self.response_catcher.response.raw_body)


    # Todo: Add description for test test_get_integer_array
    def test_get_integer_array(self):

        # Perform the API call through the SDK function
        result = self.controller.get_integer_array()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('[1,2,3,4,5]')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body))


    # Todo: Add description for test test_get_dynamic
    def test_get_dynamic(self):

        # Perform the API call through the SDK function
        result = self.controller.get_dynamic()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"method":"GET","body":{},"uploadCount":0}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_get_dynamic_array
    def test_get_dynamic_array(self):

        # Perform the API call through the SDK function
        result = self.controller.get_dynamic_array()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"method":"GET","body":{},"uploadCount":0}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_get_3339_datetime
    def test_get_3339_datetime(self):

        # Perform the API call through the SDK function
        result = self.controller.get_3339_datetime()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        self.assertEqual('2016-03-13T12:52:32.123Z', self.response_catcher.response.raw_body)


    # Todo: Add description for test test_get_3339_datetime_array
    def test_get_3339_datetime_array(self):

        # Perform the API call through the SDK function
        result = self.controller.get_3339_datetime_array()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('["2016-03-13T12:52:32.123Z","2016-03-13T12:52:32.123Z","2016-03-13T12:52:32.123Z"]')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body))


    # Todo: Add description for test test_get_boolean
    def test_get_boolean(self):

        # Perform the API call through the SDK function
        result = self.controller.get_boolean()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        self.assertEqual('true', self.response_catcher.response.raw_body)


    # Todo: Add description for test test_get_boolean_array
    def test_get_boolean_array(self):

        # Perform the API call through the SDK function
        result = self.controller.get_boolean_array()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('[true,false,true,true,false]')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body))


    # Todo: Add description for test test_get_headers_allow_extra
    def test_get_headers_allow_extra(self):

        # Perform the API call through the SDK function
        self.controller.get_headers()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)

        # Test headers
        expected_headers = {}
        expected_headers['naumanali'] = None
        expected_headers['waseemhasan'] = None

        self.assertTrue(TestHelper.match_headers(expected_headers, self.response_catcher.response.headers))


    # Todo: Add description for test test_get_1123_date_time
    def test_get_1123_date_time(self):

        # Perform the API call through the SDK function
        result = self.controller.get_1123_date_time()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        self.assertEqual('Sun, 06 Nov 1994 08:49:37 GMT', self.response_catcher.response.raw_body)


    # Todo: Add description for test test_get_unix_date_time
    def test_get_unix_date_time(self):

        # Perform the API call through the SDK function
        result = self.controller.get_unix_date_time()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        self.assertEqual('1484719381', self.response_catcher.response.raw_body)


    # Todo: Add description for test test_get_1123_date_time_array
    def test_get_1123_date_time_array(self):

        # Perform the API call through the SDK function
        result = self.controller.get_1123_date_time_array()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('["Sun, 06 Nov 1994 08:49:37 GMT","Sun, 06 Nov 1994 08:49:37 GMT"]')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body))


    # Todo: Add description for test test_get_unix_date_time_array
    def test_get_unix_date_time_array(self):

        # Perform the API call through the SDK function
        result = self.controller.get_unix_date_time_array()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('[1484719381,1484719381]')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body))


    # Todo: Add description for test test_get_content_type_in_response
    def test_get_content_type_in_response(self):

        # Perform the API call through the SDK function
        self.controller.get_content_type_headers()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)

        # Test headers
        expected_headers = {}
        expected_headers['content-type'] = 'application/responseType'
        expected_headers['accept'] = 'application/noTerm'
        expected_headers['accept-encoding'] = 'UTF-8'

        self.assertTrue(TestHelper.match_headers(expected_headers, self.response_catcher.response.headers))





# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from tests.http_response_catcher import HttpResponseCatcher
from tester.api_helper import APIHelper
from tester.controllers.query_param_controller import QueryParamController


class QueryParamControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(QueryParamControllerTests, cls).setUpClass()
        cls.response_catcher = HttpResponseCatcher()
        cls.controller = QueryParamController(cls.config, cls.response_catcher)

    def test_check_controller_type(self):
        self.assertTrue(type(self.client.query_param) is QueryParamController)

    # Todo: Add description for test test_date_array
    def test_date_array(self):
        # Parameters for the API call
        dates = [dateutil.parser.parse(element).date() for element in APIHelper.json_deserialize('["1994-02-13","1994-02-13"]')]

        # Perform the API call through the SDK function
        result = self.controller.date_array(dates)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_optional_dynamic_query_param
    def test_optional_dynamic_query_param(self):
        # Parameters for the API call
        name = 'farhan'

        # dictionary for optional query parameters
        optional_query_parameters = {}
        optional_query_parameters['field'] =  'QA'

        # Perform the API call through the SDK function
        result = self.controller.optional_dynamic_query_param(name, optional_query_parameters)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_date
    def test_date(self):
        # Parameters for the API call
        date = dateutil.parser.parse('1994-02-13').date()

        # Perform the API call through the SDK function
        result = self.controller.date(date)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_unix_date_time_array
    def test_unix_date_time_array(self):
        # Parameters for the API call
        datetimes = [element.datetime for element in APIHelper.json_deserialize('[1484719381,1484719381]', APIHelper.UnixDateTime.from_value)]

        # Perform the API call through the SDK function
        result = self.controller.unix_date_time_array(datetimes)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_unix_date_time
    def test_unix_date_time(self):
        # Parameters for the API call
        datetime = APIHelper.UnixDateTime.from_value(1484719381).datetime

        # Perform the API call through the SDK function
        result = self.controller.unix_date_time(datetime)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_rfc_1123_date_time
    def test_rfc_1123_date_time(self):
        # Parameters for the API call
        datetime = APIHelper.HttpDateTime.from_value('Sun, 06 Nov 1994 08:49:37 GMT').datetime

        # Perform the API call through the SDK function
        result = self.controller.rfc_1123_date_time(datetime)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_rfc_1123_date_time_array
    def test_rfc_1123_date_time_array(self):
        # Parameters for the API call
        datetimes = [element.datetime for element in APIHelper.json_deserialize('["Sun, 06 Nov 1994 08:49:37 GMT","Sun, 06 Nov 1994 08:49:37 GMT"]', APIHelper.HttpDateTime.from_value)]

        # Perform the API call through the SDK function
        result = self.controller.rfc_1123_date_time_array(datetimes)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_rfc_3339_date_time_array
    def test_rfc_3339_date_time_array(self):
        # Parameters for the API call
        datetimes = [element.datetime for element in APIHelper.json_deserialize('["1994-02-13T14:01:54.9571247Z","1994-02-13T14:01:54.9571247Z"]', APIHelper.RFC3339DateTime.from_value)]

        # Perform the API call through the SDK function
        result = self.controller.rfc_3339_date_time_array(datetimes)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_rfc_3339_date_time
    def test_rfc_3339_date_time(self):
        # Parameters for the API call
        datetime = APIHelper.RFC3339DateTime.from_value('1994-02-13T14:01:54.9571247Z').datetime

        # Perform the API call through the SDK function
        result = self.controller.rfc_3339_date_time(datetime)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_no_params
    def test_no_params(self):

        # Perform the API call through the SDK function
        result = self.controller.no_params()

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_string_param
    def test_string_param(self):
        # Parameters for the API call
        string = 'l;asd;asdwe[2304&&;\'.d??\\a\\\\\\;sd//'

        # Perform the API call through the SDK function
        result = self.controller.string_param(string)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_url_param
    def test_url_param(self):
        # Parameters for the API call
        url = 'https://www.shahidisawesome.com/and/also/a/narcissist?thisis=aparameter&another=one'

        # Perform the API call through the SDK function
        result = self.controller.url_param(url)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_number_array
    def test_number_array(self):
        # Parameters for the API call
        integers = APIHelper.json_deserialize('[1,2,3,4,5]')

        # Perform the API call through the SDK function
        result = self.controller.number_array(integers)

        # Test response code
        self.assertTrue(self.response_catcher.response.status_code in list(range(200, 209)))
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_string_array
    def test_string_array(self):
        # Parameters for the API call
        strings = APIHelper.json_deserialize('["abc","def"]')

        # Perform the API call through the SDK function
        result = self.controller.string_array(strings)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_simple_query
    def test_simple_query(self):
        # Parameters for the API call
        boolean = True
        number = 4
        string = 'TestString'

        # dictionary for optional query parameters
        optional_query_parameters = {}

        # Perform the API call through the SDK function
        result = self.controller.simple_query(boolean, number, string, optional_query_parameters)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_string_enum_array
    def test_string_enum_array(self):
        # Parameters for the API call
        days = APIHelper.json_deserialize('["Tuesday","Saturday","Wednesday","Monday","Sunday"]')

        # Perform the API call through the SDK function
        result = self.controller.string_enum_array(days)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_multiple_params
    def test_multiple_params(self):
        # Parameters for the API call
        number = 123412312
        precision = 1112.34
        string = '""test./;";12&&3asl"";"qw1&34"///..//.'
        url = 'http://www.abc.com/test?a=b&c="http://lolol.com?param=no&another=lol"'

        # Perform the API call through the SDK function
        result = self.controller.multiple_params(number, precision, string, url)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_integer_enum_array
    def test_integer_enum_array(self):
        # Parameters for the API call
        suites = APIHelper.json_deserialize('[1,3,4,2,3]')

        # Perform the API call through the SDK function
        result = self.controller.integer_enum_array(suites)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"passed":true}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))





# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""
import tester.models.medication
import tester.models.lab
import tester.models.imaging


class Complex1(object):

    """Implementation of the 'complex1' model.

    TODO: type model description here.

    Attributes:
        medications (list of Medication): TODO: type description here.
        labs (list of Lab): TODO: type description here.
        imaging (list of Imaging): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "imaging": 'imaging',
        "labs": 'labs',
        "medications": 'medications'
    }

    def __init__(self,
                 imaging=None,
                 labs=None,
                 medications=None,
                 additional_properties={}):
        """Constructor for the Complex1 class"""

        # Initialize members of the class
        self.medications = medications
        self.labs = labs
        self.imaging = imaging

        # Add additional model properties to the instance
        self.additional_properties = additional_properties

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        imaging = None
        if dictionary.get('imaging') is not None:
            imaging = [tester.models.imaging.Imaging.from_dictionary(x) for x in dictionary.get('imaging')]
        labs = None
        if dictionary.get('labs') is not None:
            labs = [tester.models.lab.Lab.from_dictionary(x) for x in dictionary.get('labs')]
        medications = None
        if dictionary.get('medications') is not None:
            medications = [tester.models.medication.Medication.from_dictionary(x) for x in dictionary.get('medications')]

        # Clean out expected properties from dictionary
        for key in cls._names.values():
            if key in dictionary:
                del dictionary[key]

        # Return an object of this model
        return cls(imaging,
                   labs,
                   medications,
                   dictionary)



# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""


class Company(object):

    """Implementation of the 'Company' model.

    TODO: type model description here.

    Attributes:
        company_name (string): TODO: type description here.
        address (string): TODO: type description here.
        cell_number (string): TODO: type description here.
        company (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "address": 'address',
        "cell_number": 'cell number',
        "company_name": 'company name',
        "company": 'company'
    }

    def __init__(self,
                 address=None,
                 cell_number=None,
                 company_name=None,
                 company=None,
                 additional_properties={}):
        """Constructor for the Company class"""

        # Initialize members of the class
        self.company_name = company_name
        self.address = address
        self.cell_number = cell_number
        self.company = company

        # Add additional model properties to the instance
        self.additional_properties = additional_properties

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        discriminators = {
            'boss_comp': BossCompany.from_dictionary,
            'empl_comp': EmployeeComp.from_dictionary,
            'Software_Tester': SoftwareTester.from_dictionary
        }
        unboxer = discriminators.get(dictionary.get('company'))

        # Delegate unboxing to another function if a discriminator
        # value for a child class is present.
        if unboxer:
            return unboxer(dictionary)

        # Extract variables from the dictionary
        address = dictionary.get('address')
        cell_number = dictionary.get('cell number')
        company_name = dictionary.get('company name')
        company = dictionary.get('company')

        # Clean out expected properties from dictionary
        for key in cls._names.values():
            if key in dictionary:
                del dictionary[key]

        # Return an object of this model
        return cls(address,
                   cell_number,
                   company_name,
                   company,
                   dictionary)


class BossCompany(Company):

    """Implementation of the 'Boss_company' model.

    TODO: type model description here.
    NOTE: This class inherits from 'Company'.

    Attributes:
        first_name (string): TODO: type description here.
        last_name (string): TODO: type description here.
        address_boss (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "address": 'address',
        "address_boss": 'address_boss',
        "cell_number": 'cell number',
        "company_name": 'company name',
        "first_name": 'first name',
        "last_name": 'last name',
        "company": 'company'
    }

    def __init__(self,
                 address=None,
                 address_boss=None,
                 cell_number=None,
                 company_name=None,
                 first_name=None,
                 last_name=None,
                 company=None,
                 additional_properties={}):
        """Constructor for the BossCompany class"""

        # Initialize members of the class
        self.first_name = first_name
        self.last_name = last_name
        self.address_boss = address_boss

        # Add additional model properties to the instance
        self.additional_properties = additional_properties

        # Call the constructor for the base class
        super(BossCompany, self).__init__(address,
                                          cell_number,
                                          company_name,
                                          company)

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        address = dictionary.get('address')
        address_boss = dictionary.get('address_boss')
        cell_number = dictionary.get('cell number')
        company_name = dictionary.get('company name')
        first_name = dictionary.get('first name')
        last_name = dictionary.get('last name')
        company = dictionary.get('company')

        # Clean out expected properties from dictionary
        for key in cls._names.values():
            if key in dictionary:
                del dictionary[key]

        # Return an object of this model
        return cls(address,
                   address_boss,
                   cell_number,
                   company_name,
                   first_name,
                   last_name,
                   company,
                   dictionary)


class EmployeeComp(Company):

    """Implementation of the 'employee_comp' model.

    TODO: type model description here.
    NOTE: This class inherits from 'Company'.

    Attributes:
        first_name (string): TODO: type description here.
        last_name (string): TODO: type description here.
        id (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "address": 'address',
        "cell_number": 'cell number',
        "company_name": 'company name',
        "first_name": 'first name',
        "id": 'id',
        "last_name": 'last name',
        "company": 'company'
    }

    def __init__(self,
                 address=None,
                 cell_number=None,
                 company_name=None,
                 first_name=None,
                 id=None,
                 last_name=None,
                 company=None,
                 additional_properties={}):
        """Constructor for the EmployeeComp class"""

        # Initialize members of the class
        self.first_name = first_name
        self.last_name = last_name
        self.id = id

        # Add additional model properties to the instance
        self.additional_properties = additional_properties

        # Call the constructor for the base class
        super(EmployeeComp, self).__init__(address,
                                           cell_number,
                                           company_name,
                                           company)

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        discriminators = {
            'Software_Tester': SoftwareTester.from_dictionary
        }
        unboxer = discriminators.get(dictionary.get('company'))

        # Delegate unboxing to another function if a discriminator
        # value for a child class is present.
        if unboxer:
            return unboxer(dictionary)

        # Extract variables from the dictionary
        address = dictionary.get('address')
        cell_number = dictionary.get('cell number')
        company_name = dictionary.get('company name')
        first_name = dictionary.get('first name')
        id = dictionary.get('id')
        last_name = dictionary.get('last name')
        company = dictionary.get('company')

        # Clean out expected properties from dictionary
        for key in cls._names.values():
            if key in dictionary:
                del dictionary[key]

        # Return an object of this model
        return cls(address,
                   cell_number,
                   company_name,
                   first_name,
                   id,
                   last_name,
                   company,
                   dictionary)


class SoftwareTester(EmployeeComp):

    """Implementation of the 'Software Tester' model.

    TODO: type model description here.
    NOTE: This class inherits from 'EmployeeComp'.

    Attributes:
        team (string): TODO: type description here.
        designation (string): TODO: type description here.
        role (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "address": 'address',
        "cell_number": 'cell number',
        "company_name": 'company name',
        "designation": 'designation',
        "first_name": 'first name',
        "id": 'id',
        "last_name": 'last name',
        "role": 'role',
        "team": 'team',
        "company": 'company'
    }

    def __init__(self,
                 address=None,
                 cell_number=None,
                 company_name=None,
                 designation=None,
                 first_name=None,
                 id=None,
                 last_name=None,
                 role=None,
                 team=None,
                 company=None,
                 additional_properties={}):
        """Constructor for the SoftwareTester class"""

        # Initialize members of the class
        self.team = team
        self.designation = designation
        self.role = role

        # Add additional model properties to the instance
        self.additional_properties = additional_properties

        # Call the constructor for the base class
        super(SoftwareTester, self).__init__(address,
                                             cell_number,
                                             company_name,
                                             first_name,
                                             id,
                                             last_name,
                                             company)

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        address = dictionary.get('address')
        cell_number = dictionary.get('cell number')
        company_name = dictionary.get('company name')
        designation = dictionary.get('designation')
        first_name = dictionary.get('first name')
        id = dictionary.get('id')
        last_name = dictionary.get('last name')
        role = dictionary.get('role')
        team = dictionary.get('team')
        company = dictionary.get('company')

        # Clean out expected properties from dictionary
        for key in cls._names.values():
            if key in dictionary:
                del dictionary[key]

        # Return an object of this model
        return cls(address,
                   cell_number,
                   company_name,
                   designation,
                   first_name,
                   id,
                   last_name,
                   role,
                   team,
                   company,
                   dictionary)


class Developer(EmployeeComp):

    """Implementation of the 'developer' model.

    TODO: type model description here.
    NOTE: This class inherits from 'EmployeeComp'.

    Attributes:
        team (string): TODO: type description here.
        designation (string): TODO: type description here.
        role (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "address": 'address',
        "cell_number": 'cell number',
        "company_name": 'company name',
        "designation": 'designation',
        "first_name": 'first name',
        "id": 'id',
        "last_name": 'last name',
        "role": 'role',
        "team": 'team',
        "company": 'company'
    }

    def __init__(self,
                 address=None,
                 cell_number=None,
                 company_name=None,
                 designation=None,
                 first_name=None,
                 id=None,
                 last_name=None,
                 role=None,
                 team=None,
                 company=None,
                 additional_properties={}):
        """Constructor for the Developer class"""

        # Initialize members of the class
        self.team = team
        self.designation = designation
        self.role = role

        # Add additional model properties to the instance
        self.additional_properties = additional_properties

        # Call the constructor for the base class
        super(Developer, self).__init__(address,
                                        cell_number,
                                        company_name,
                                        first_name,
                                        id,
                                        last_name,
                                        company)

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        address = dictionary.get('address')
        cell_number = dictionary.get('cell number')
        company_name = dictionary.get('company name')
        designation = dictionary.get('designation')
        first_name = dictionary.get('first name')
        id = dictionary.get('id')
        last_name = dictionary.get('last name')
        role = dictionary.get('role')
        team = dictionary.get('team')
        company = dictionary.get('company')

        # Clean out expected properties from dictionary
        for key in cls._names.values():
            if key in dictionary:
                del dictionary[key]

        # Return an object of this model
        return cls(address,
                   cell_number,
                   company_name,
                   designation,
                   first_name,
                   id,
                   last_name,
                   role,
                   team,
                   company,
                   dictionary)



# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""


class Status(object):

    """Implementation of the 'Status' model.

    TODO: type model description here.

    Attributes:
        document_status (string): TODO: type description here.
        completed_packages (list of string): TODO: type description here.
        attachment_packages (object): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "attachment_packages": 'attachmentPackages',
        "completed_packages": 'completedPackages',
        "document_status": 'documentStatus'
    }

    def __init__(self,
                 attachment_packages=None,
                 completed_packages=None,
                 document_status=None,
                 additional_properties={}):
        """Constructor for the Status class"""

        # Initialize members of the class
        self.document_status = document_status
        self.completed_packages = completed_packages
        self.attachment_packages = attachment_packages

        # Add additional model properties to the instance
        self.additional_properties = additional_properties

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        attachment_packages = dictionary.get('attachmentPackages')
        completed_packages = dictionary.get('completedPackages')
        document_status = dictionary.get('documentStatus')

        # Clean out expected properties from dictionary
        for key in cls._names.values():
            if key in dictionary:
                del dictionary[key]

        # Return an object of this model
        return cls(attachment_packages,
                   completed_packages,
                   document_status,
                   dictionary)



# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""

from tester.api_helper import APIHelper
from tester.configuration import Configuration
from tester.configuration import Server
from tester.controllers.base_controller import BaseController
from tester.models.server_response import ServerResponse


class HeaderController(BaseController):

    """A Controller to access Endpoints in the tester API."""

    def __init__(self, config, call_back=None):
        super(HeaderController, self).__init__(config, call_back)

    def send_headers(self,
                     custom_header,
                     value):
        """Does a POST request to /header.

        Sends a single header params

        Args:
            custom_header (string): TODO: type description here.
            value (string): Represents the value of the custom header

        Returns:
            ServerResponse: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Validate required parameters
        self.validate_parameters(custom_header=custom_header,
                                 value=value)

        # Prepare query URL
        _url_path = '/header'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'custom-header': custom_header
        }

        # Prepare form parameters
        _form_parameters = {
            'value': value
        }

        # Prepare and execute request
        _request = self.config.http_client.post(_query_url, headers=_headers, parameters=_form_parameters)
        _response = self.execute_request(_request)

        # Endpoint and global error handling using HTTP status codes.
        if _response.status_code == 404:
            return None
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.raw_body, ServerResponse.from_dictionary)

        return decoded



# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""


class SuiteCode(object):

    """Implementation of the 'SuiteCode' enum.

    A integer based enum representing a Suite in a game of cards

    Attributes:
        HEARTS: TODO: type description here.
        SPADES: TODO: type description here.
        CLUBS: TODO: type description here.
        DIAMONDS: TODO: type description here.

    """

    HEARTS = 1

    SPADES = 2

    CLUBS = 3

    DIAMONDS = 4



# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from tests.http_response_catcher import HttpResponseCatcher
from tester.api_helper import APIHelper
from tester.controllers.template_params_controller import TemplateParamsController


class TemplateParamsControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(TemplateParamsControllerTests, cls).setUpClass()
        cls.response_catcher = HttpResponseCatcher()
        cls.controller = TemplateParamsController(cls.config, cls.response_catcher)

    def test_check_controller_type(self):
        self.assertTrue(type(self.client.template_params) is TemplateParamsController)

    # Todo: Add description for test test_send_string_array
    def test_send_string_array(self):
        # Parameters for the API call
        strings = APIHelper.json_deserialize('["abc","def"]')

        # Perform the API call through the SDK function
        result = self.controller.send_string_array(strings)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"path":"/abc/def"}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))


    # Todo: Add description for test test_send_integer_array
    def test_send_integer_array(self):
        # Parameters for the API call
        integers = APIHelper.json_deserialize('[1,2,3,4,5]')

        # Perform the API call through the SDK function
        result = self.controller.send_integer_array(integers)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)
        
        # Test whether the captured response is as we expected
        self.assertIsNotNone(result)
        expected_body = APIHelper.json_deserialize('{"path":"/1/2/3/4/5"}')
        received_body = APIHelper.json_deserialize(self.response_catcher.response.raw_body)
        self.assertTrue(TestHelper.match_body(expected_body, received_body, check_values = True))





# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""
import tester.models.signer
import tester.models.status
import tester.models.data_to_sign
import tester.models.contact_details
import tester.models.advanced


class Complex3(object):

    """Implementation of the 'complex3' model.

    TODO: type model description here.

    Attributes:
        document_id (string): TODO: type description here.
        signers (list of Signer): TODO: type description here.
        status (Status): TODO: type description here.
        title (string): TODO: type description here.
        description (string): TODO: type description here.
        external_id (string): TODO: type description here.
        data_to_sign (DataToSign): TODO: type description here.
        contact_details (ContactDetails): TODO: type description here.
        advanced (Advanced): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "advanced": 'advanced',
        "contact_details": 'contactDetails',
        "data_to_sign": 'dataToSign',
        "description": 'description',
        "document_id": 'documentId',
        "external_id": 'externalId',
        "signers": 'signers',
        "status": 'status',
        "title": 'title'
    }

    def __init__(self,
                 advanced=None,
                 contact_details=None,
                 data_to_sign=None,
                 description=None,
                 document_id=None,
                 external_id=None,
                 signers=None,
                 status=None,
                 title=None,
                 additional_properties={}):
        """Constructor for the Complex3 class"""

        # Initialize members of the class
        self.document_id = document_id
        self.signers = signers
        self.status = status
        self.title = title
        self.description = description
        self.external_id = external_id
        self.data_to_sign = data_to_sign
        self.contact_details = contact_details
        self.advanced = advanced

        # Add additional model properties to the instance
        self.additional_properties = additional_properties

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        advanced = tester.models.advanced.Advanced.from_dictionary(dictionary.get('advanced')) if dictionary.get('advanced') else None
        contact_details = tester.models.contact_details.ContactDetails.from_dictionary(dictionary.get('contactDetails')) if dictionary.get('contactDetails') else None
        data_to_sign = tester.models.data_to_sign.DataToSign.from_dictionary(dictionary.get('dataToSign')) if dictionary.get('dataToSign') else None
        description = dictionary.get('description')
        document_id = dictionary.get('documentId')
        external_id = dictionary.get('externalId')
        signers = None
        if dictionary.get('signers') is not None:
            signers = [tester.models.signer.Signer.from_dictionary(x) for x in dictionary.get('signers')]
        status = tester.models.status.Status.from_dictionary(dictionary.get('status')) if dictionary.get('status') else None
        title = dictionary.get('title')

        # Clean out expected properties from dictionary
        for key in cls._names.values():
            if key in dictionary:
                del dictionary[key]

        # Return an object of this model
        return cls(advanced,
                   contact_details,
                   data_to_sign,
                   description,
                   document_id,
                   external_id,
                   signers,
                   status,
                   title,
                   dictionary)



# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""


class ParamFormat(object):

    """Implementation of the 'ParamFormat' enum.

    TODO: type enum description here.

    Attributes:
        TEMPLATE: TODO: type description here.
        FORM: TODO: type description here.
        BODY: TODO: type description here.
        HEADER: TODO: type description here.
        QUERY: TODO: type description here.

    """

    TEMPLATE = 'Template'

    FORM = 'Form'

    BODY = 'Body'

    HEADER = 'Header'

    QUERY = 'Query'



# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""
import tester.models.time_to_live


class Advanced(object):

    """Implementation of the 'Advanced' model.

    TODO: type model description here.

    Attributes:
        tags (list of string): TODO: type description here.
        attachments (int): TODO: type description here.
        required_signatures (int): TODO: type description here.
        get_social_security_number (bool): TODO: type description here.
        time_to_live (TimeToLive): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "attachments": 'attachments',
        "get_social_security_number": 'getSocialSecurityNumber',
        "required_signatures": 'requiredSignatures',
        "tags": 'tags',
        "time_to_live": 'timeToLive'
    }

    def __init__(self,
                 attachments=None,
                 get_social_security_number=None,
                 required_signatures=None,
                 tags=None,
                 time_to_live=None,
                 additional_properties={}):
        """Constructor for the Advanced class"""

        # Initialize members of the class
        self.tags = tags
        self.attachments = attachments
        self.required_signatures = required_signatures
        self.get_social_security_number = get_social_security_number
        self.time_to_live = time_to_live

        # Add additional model properties to the instance
        self.additional_properties = additional_properties

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        attachments = dictionary.get('attachments')
        get_social_security_number = dictionary.get('getSocialSecurityNumber')
        required_signatures = dictionary.get('requiredSignatures')
        tags = dictionary.get('tags')
        time_to_live = tester.models.time_to_live.TimeToLive.from_dictionary(dictionary.get('timeToLive')) if dictionary.get('timeToLive') else None

        # Clean out expected properties from dictionary
        for key in cls._names.values():
            if key in dictionary:
                del dictionary[key]

        # Return an object of this model
        return cls(attachments,
                   get_social_security_number,
                   required_signatures,
                   tags,
                   time_to_live,
                   dictionary)



__all__ = [
    'api_exception',
    'local_test_exception',
    'global_test_exception',
    'nested_model_exception',
    'rfc_1123_exception',
    'unix_time_stamp_exception',
    'exception_with_rfc_3339_date_time_exception',
    'exception_with_date_exception',
    'exception_with_uuid_exception',
    'exception_with_dynamic_exception',
    'exception_with_precision_exception',
    'exception_with_boolean_exception',
    'exception_with_long_exception',
    'exception_with_number_exception',
    'exception_with_string_exception',
    'custom_error_response_exception',
    'send_uuid_in_model_as_exception',
    'send_precision_in_model_as_exception',
    'send_number_in_model_as_exception',
    'send_long_in_model_as_exception',
    'send_string_in_model_as_exception',
    'send_dynamic_in_model_as_exception',
    'send_date_in_model_as_exception',
    'send_unix_time_stamp_in_model_as_exception',
    'send_rfc_3339_in_model_as_exception',
    'send_rfc_1123_in_model_as_exception',
    'send_boolean_in_model_as_exception',
    'complex_object_in_exception',
    'enum_in_exception',
]



# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""

from tester.api_helper import APIHelper
import tester.exceptions.api_exception
import tester.models.add_rfc_3339_datetime_in_global_exception


class SendRfc3339InModelAsException(tester.exceptions.api_exception.APIException):
    def __init__(self, reason, response):
        """Constructor for the SendRfc3339InModelAsException class

        Args:
            reason (string): The reason (or error message) for the Exception
                to be raised.
            response (HttpResponse): The HttpResponse of the API call.

        """
        super(SendRfc3339InModelAsException, self).__init__(reason, response)
        dictionary = APIHelper.json_deserialize(self.response.raw_body)
        if isinstance(dictionary, dict):
            self.unbox(dictionary)

    def unbox(self, dictionary):
        """Populates the properties of this object by extracting them from a dictionary.

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        """
        self.body = tester.models.add_rfc_3339_datetime_in_global_exception.AddRfc3339DatetimeInGlobalException.from_dictionary(dictionary.get('body')) if dictionary.get('body') else None



# -*- coding: utf-8 -*-

"""
tester

This file was automatically generated for Stamplay by APIMATIC v2.0 (
 https://apimatic.io ).
"""


class Team(object):

    """Implementation of the 'team' enum.

    TODO: type enum description here.

    Attributes:
        CODEGEN: TODO: type description here.
        CGAAS: TODO: type description here.
        UX: TODO: type description here.
        QA: TODO: type description here.

    """

    CODEGEN = 'codegen'

    CGAAS = 'cgaas'

    UX = 'ux'

    QA = 'qa'
